# MasterThesis2023

This is the code repository for master thesis of Grosu Cristian for 2023 at Utrecht University

## Usage guide

Run the following command to install the needed dependencies: `pip install -r requirements.txt`
Run the following command to start the application `python3 mainGUI.py`
Run the following script to get an example of how the Decision Boundary Mapper works `python3 main.py`

## Tasks to be done

### 1) Think about a way of how to upload the data to the GUI faster

This is not really an issue

### 2) Write the API interface documentation

...

# API Documentation

TODO
